import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { NzCardModule } from 'ng-zorro-antd/card';
import { NzInputModule } from 'ng-zorro-antd/input'
import { NzButtonModule } from 'ng-zorro-antd/button';
import { NzIconModule } from 'ng-zorro-antd/icon';
import { NzCheckboxModule } from 'ng-zorro-antd/checkbox';
import { NzFormModule } from 'ng-zorro-antd/form';
import { NzAlertModule } from 'ng-zorro-antd/alert';

import { CommonModule } from '@angular/common';
import { FormBuilder, FormGroup, FormsModule, ReactiveFormsModule, Validators } from '@angular/forms';
import { catchError, finalize, Observable, of, tap } from 'rxjs';
import { AuthService } from '../data-access/Services/ApiService.service';
import { response } from 'express';
@Component({
  selector: 'meu-login',
  standalone: true,
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss'],
  imports: [CommonModule,
    FormsModule,
    ReactiveFormsModule,
    NzFormModule,
    NzCardModule,
    NzInputModule,
    NzButtonModule,
    NzIconModule,
    NzCheckboxModule,
    NzAlertModule,
    NzFormModule,
    ReactiveFormsModule,
],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class LoginComponent implements OnInit {
  MgsError: string = '';

  loginForm: FormGroup;
  constructor(private fb: FormBuilder, private authService: AuthService) {
    this.loginForm = this.fb.group({
      userName: ['', [Validators.required]],
      password: ['', [Validators.required]],
    });
  }
  ngOnInit() {}
  saveInfo(res: any) {
    localStorage.setItem('token', res.responseData.token);
    localStorage.setItem('expirationTime', res.responseData.expirationTime);
    localStorage.setItem('role', res.responseData.role);
  }
  onSubmit() {
    if (!this.loginForm.valid) {
      this.MgsError = "Vui lòng nhập thống tin đăng nhập";
      return;
    }
    console.log(this.loginForm.value.userName, this.loginForm.value.password);

    this.authService.login(this.loginForm.value.userName, this.loginForm.value.password).pipe(
      tap((res) => { // không ảnh hưởng đến data trên observable
          this.saveInfo(res);
          window.location.href = '/admin';
      }),
      catchError((err) => {
        this.MgsError = err.message;
        console.log(this.MgsError);
        console.log(err);
        return of(null);
      }),
      finalize(() => { // gọi ra khi observable hoàn tất
        console.log('Login request completed');
      })
    ).subscribe();
  }
}
